@@ -14,10 +14,17 @@ class PlayerMetric:
         """
         if df == "boxscore":
             df = self.df_boxscore
+            df['mp'] = df['mp'].fillna("0:0")
         elif df == "all":
             df = self.df_all
         else:
             raise Exception("You can only only provide all or boxscore in the preprocess function. Please try again with the approciate parameters!")
+
+        # drop index or unnamed columns
+        try:
+            df.drop(list(df.filter(regex = '(unnamed)|(^index)')), axis = 1, inplace = True)
+        except:
+            print("no column unnamed!")
         
         df.columns = [col_name.lower() for col_name in df.columns]
         df = df.fillna(0)
@@ -29,8 +36,8 @@ class PlayerMetric:
         self.df_boxscore = per_game_metric_helper.touches(self.df_boxscore)
         self.df_boxscore = per_game_metric_helper.versatility_index(self.df_boxscore)
         self.df_boxscore = per_game_metric_helper.defensive_versatility_idx(self.df_boxscore)
+        self.df_boxscore = per_game_metric_helper.bbref_scoring_possessions_and_offense_rating(self.df_boxscore)
         self.df_boxscore = per_game_metric_helper.non_scoring_possessions(self.df_boxscore)
-        self.df_boxscore = per_game_metric_helper.scoring_possessions(self.df_boxscore)
         self.df_boxscore = per_game_metric_helper.win_score(self.df_boxscore)
         self.df_boxscore = per_game_metric_helper.individual_floor_percentage(self.df_boxscore)
         self.df_boxscore = per_game_metric_helper.player_impact_estimate(self.df_boxscore)
